function dy = mantle_equations(t,y)

%%%%%%% Mantle Model: PhD thesis version.
%%%%%%% Benjamin Mills. Dec 2012. benjaminmills@live.com
%%%%%%%
%%%%%%% Extension of Minimal Model -
%%%%%%% additional fluxes added to represent inputs from the mantle,
%%%%%%% subduction to the mantle, and carbonatization of ocean crust.
%%%%%%% 
%%%%%%% 
%%%%%%% Model equations file
%%%%%%%
%%%%%%% User panel line 190





%%%%%%% setup dy vector
dy = zeros(53,1);  

%%%%%%% import globals
global telltime
global k1
global k2
global k3
global k4
global k5
global k7
global k8
global k9
global k10
global a
global b
global d
global k_pyrb
global k_gypb
global P0
global O0
global A0
global G0
global C0
global PYR0
global GYP0
global S0
global alpha
global variable_d_ocw
global variable_d_mocb
global variable_d_locb
global kcarbw
global k11
global klocb
global kfire
global copsek16
global k_pyrdeg
global k_gypdeg
global k_pyrw
global k_gypw
global plantenhance
global k_hydro
global k_pyrmelt
global k_ridge
global k_od
global k_cd
global k_pd
global k_gd
global variable_d_mpsb
global variable_d_MPYR 
global variable_d_MC
global k_oxyiron
global dmccbfraceffect
global mpsbfraceffect
global TLIMIT
global tlimitchoice





%%%%%%% define functions as inline


%%%%%%% atmospheric fraction of total CO2, atfrac(A)

%%%%%%% constant
% atfrac=inline('1');

%%%% mills2011 atfrac - valid for albedo = {0.3,0.6} only
atfrac=inline(' 0.8.*( x./(x  +  (    1    ).*10^20  ) )  ');



%%%%%%% temperature (x) and CO2 (y) dependence of weathering
fco2=inline(  ' exp(7537.69.*((x-288.15)./(x.*288.15))).*((exp( 0.03.*(x-288.15) )).^0.65).*((y).^0.5)  ' ); 
gco2=inline( ' exp(0.05*(x-288.15)).*((y).^0.5)  '); 
% gco2=fco2;


%%%%%%% ocean anoxic fraction (COPSE) - negative values truncated to zero
anox=inline('(0.*(1 - 0.5.*(sign((1-((0.86*(x./(3.7*10^19)))./(y./(3.1*10^15))))) + 1)) + (1-((0.86.*(x./(3.7*10^19)))./(y./(3.1*10^15)))).*0.5.*(sign((1-((0.86*(x./(3.7*10^19)))./(y./(3.1*10^15)))))+1 ))');


%%%%%%% C to P burial ratio (COPSE)
CPsea=inline('250');  


% PYR burial function (COPSE)
fox=inline('1/(x/(3.7*10^19))') ; 






%%%%%%% define forcing functions, forcings for model run are chosen later.



%%%%%%% CP land doubles in permo-carboniferous (COPSE)
CPlandrel = inline(' interp1([0 4.14E9 4.15E9 4.2E9 4.21E9 1E10 ],[1 1 2 2 1 1],x)  ') ;


%%%%%%% time-dependent solar insolation (NORMALISED TO PRESENT)
CK_solar=inline(' 1./(1+((((4.5*10^9)-x)./(4.55*10^9))*0.38))');  


%%%%%%% COPSE B forcing (calcerous plankton evolution)
COPSE_B = inline(' interp1([0 4.00E+09	4.20E+09	4.35E+09	4.36E+09	4.39E+09	4.41E+09	4.45E+09	4.49E+09	4.50E+09 1E10],[0.75  0.75	0.75	0.75	0.83776596	0.90990691	0.96110372	0.98902926	1	1  1],x)  ');


%%%%%%% Vnpp (OCT feedback on vegitation, COPSE)
%%%%%%% f(Evolution forcing, Ontp, Pco2, Temp)
COPSE_Vnpp = inline(' 2.*a.*( 1.5 -  0.5.*b  ).*(    ( c - 10 )/( 183.6 + c  - 10  )    ).*(  1-  (( (d - 298) ./ 298  ).^2)   )           ') ;


%%%%%%% COPSE evolution forcing
COPSE_E = inline(' interp1([0  4.08E+09	4.10E+09	4.12E+09	4.14E+09	4.19E+09	4.20E+09	4.28E+09 1E10],[0 0.002327128	0.15359043	0.25365691	0.48869681	0.9005984	1 1 1],x)   ');


%%%%%%% COPSE weathering forcing
COPSE_W = inline( '  interp1([0  4.03E+09	4.06E+09	4.08E+09	4.10E+09	4.12E+09	4.15E+09	4.17E+09	4.20E+09	4.32E+09	4.39E+09	4.40E+09	4.50E+09 1E10],[0  0.006981383	0.025598404	0.025598404	0.097739362	0.15359043	0.42353723	0.60970745	0.75	0.75	0.75	1	1  1],x)   ' );


%%%%%%% uplift
long_combined_uplift = inline('interp1([1998737100	2025438600	2058073700	2084775200	2129277600	2164879600	2209382000	2271685400	2348823000	2434861100	2500131400	2547600600	2592103100	2633638700	2672207500	2710776300	2743411400	2787913900	2829449500	2856151000	2891752900	2933288500	2983724700	3037127600	3093497400	3146900300	3206236900	3277440800	3351611600	3434682800	3494019400	3553356000	3609725800	3630493600	3657195100	3686863400	3716531700	3728399000	3737299500	3749166800	3766967800	3805536600	3853005900	3903442000	3939043900	3953878100	3962778600	3971679100	3980579600	4001347400	4010247900	4028048800	4033982500	4036949300	4039916200	4045849800	4051783500	4063650800	4069584500	4072551300	4075518100	4081451800	4087385400	4102219600	4105186400	4111120100	4114086900	4117053700	4120020600	4128921100	4131887900	4140788400	4149688900	4152655700	4155622500	4161556200	4164523000	4167489800	4176390300	4182324000	4188257700	4191224500	4200125000	4209025500	4211992300	4214959100	4217926000	4220892800	4223859600	4226826400	4235726900	4244627400	4250561100	4253527900	4254527900	4259461600	4259561600	4259661600	4262428400	4271328900	4274295700	4274495700	4277262600	4292096700	4295063500	4303964000	4303965000	4309897700	4315831400	4321765000	4330665500	4333632300	4339566000	4357367000	4363300600	4363300700	4372201100	4375168000	4381101600	4387035300	4395935800	4401869400	4410769900	4416703600	4425604100	4431537700	4443405000	4449338700	4452305500	4458239200	4464172900	4476040200	4481973800	4484940700	4487907500	4488907500	4493841200	4.5e9 10e9],[0.68561525	0.72928943	0.78232236	0.83067591	0.88526863	0.92894281	0.97417678	1.0365685	1.0818024	1.1285962	1.1488735	1.1582322	1.1551127	1.1504333	1.1410745	1.1207972	1.0989601	1.0677643	1.0303293	1.002253	0.97261698	0.94610052	0.91334489	0.88370884	0.84939341	0.81507799	0.79480069	0.7729636	0.75580589	0.73864818	0.72149047	0.71369151	0.70901213	0.7152513	0.74488735	0.77764298	0.82287695	0.85875217	0.88994801	0.91646447	0.9305026	0.95701906	0.98197574	1.0038128	1.0381282	1.0646447	1.1005199	1.1363951	1.159792	1.1348354	1.0958406	1.0740035	1.039688	0.97885615	0.93674177	0.88838821	0.84939341	0.85407279	0.89462738	0.94610052	0.98353553	1.0194107	1.0365685	0.9882149	0.94610052	0.90554593	0.85095321	0.81819757	0.80259965	0.79168111	0.83379549	0.89306759	0.8712305	0.83847487	0.80883882	0.78076256	0.74644714	0.72149047	0.75580589	0.78544194	0.8135182	0.83847487	0.86343154	0.82287695	0.79480069	0.80415945	0.7729636	0.7339688	0.67781629	0.64662045	0.60918544	0.55615251	0.64194107	0.59670711	0.68717504	0.7355286	0.76984402	0.7542461	0.78856153	0.8135182	0.76984402	0.73864818	0.72305026	0.71213172	0.69341421	0.66377816	0.61230503	0.58578856	0.55615251	0.59982669	0.5779896	0.54835355	0.53431542	0.5592721	0.59202773	0.62946274	0.66533795	0.70121317	0.73708839	0.7152513	0.75268631	0.73240901	0.71369151	0.68093588	0.71681109	0.74800693	0.7745234	0.76672444	0.7745234	0.74800693	0.74176776	0.78544194	0.81507799	0.85719237	0.92426343	0.9507799	0.97729636	1 1],x)') ;


%%%%%%% degassing
Jam_squared_degassing =  inline(  '  interp1( [1498966600	1672794900	1816493000	1876753500	1897612900	1934696200	2096936000	2261493400	2305529900	2405191500	2630009400	2815426300	3163082800	3675296900	3895479400	3923291900	3944151300	3960375300	3.97E+09	3.98E+09	3.99E+09	4.00E+09	4.02E+09	4.04E+09	4.06E+09	4.08E+09	4.10E+09	4.11E+09	4.14E+09	4.15E+09	4.16E+09	4.17E+09	4.18E+09	4.20E+09	4.21E+09	4.22E+09	4.225E+09	4.24E+09	4.245E+09	4.26E+09	4.29E+09	4.31E+09	4.32E+09	4.34E+09	4.35E+09	4.36E+09	4.37E+09	4.39E+09	4.40E+09	4.41E+09	4.42E+09	4.43E+09	4.44E+09	4.45E+09	4.46E+09	4.47E+09	4.48E+09	4.50E+09 1E10 ]   ,  [ 7.2088608	6.8556962	6.5822785	6.4797468	6.3886076	6.1607595	5.2265823	4.3493671	4.1556962	3.8594937	3.2556962	2.8	2.2759494	1.6265823	1.3987342	1.3987342	1.421519	1.5012658 	1.5877483	1.6978477	1.6283113	1.5413907	1.5008278	1.5413907	1.5761589	1.5413907	1.419702	1.361755	1.4254967	1.419702	1.263245	1.089404	1.1009934	1.1821192	1.2168874	1.1009934	1.0720199	1.1357616	1.1357616	1.089404	1.1299669	1.089404	1.1589404	1.2690397	1.0198675	0.98509934	1.4892384	1.7094371	1.6572848	1.3675497	1.3327815	1.3501656	1.3443709	1.4486755	1.1995033	1.0662252	0.99089404	1  1 ]  ,x)    '  );


%%%%%%% mantle input for carbon from hayes and waldbaur (2006) 
Jam=inline(  '  interp1([0	1.89E+09	2.30E+09	2.81E+09	3.56E+09	4.07E+09	4.50E+09 10*10^9],(1/(2.2*10^12))*[	7.12781E+12	5.58287E+12	4.49438E+12	3.6868E+12	2.91433E+12	2.42E+12	2.2E+12 2.2E+12],x)  '  );


%%%%%%% continental area (mclennan+taylor, rino) 
CA_macandtal = inline(' interp1([1665351400	2038941200	2093126000	2552270700	2580789000	2743343400	4380294200	4497219200],[0	0.092985318	0.12724307	0.77977162	0.80097879	0.82218597	0.99673736	1],x) ') ;
rino_contarea = inline('interp1([0	1.82E+09	1.94E+09	2.03E+09	2.15E+09	2.30E+09	2.36E+09	2.54E+09	2.68E+09	2.84E+09	3.00E+09	3.26E+09	3.47E+09	3.58E+09	3.72E+09	3.94E+09	4.13E+09	4.31E+09	4.50E+09	1.00E+10],[0.25614035 0.25614035	0.25614035	0.29473684	0.31578947	0.35789474	0.44210526	0.56491228	0.61403509	0.67719298	0.72982456	0.8245614	0.89824561	0.94035088	0.95789474	0.96491228	0.98245614	0.99649123	1	1],x)');



%%%%%%% neoproterozoic continental position forcing (PW1)
neop_runoff=inline('(x-w).*(1./(1+exp(-2*(6*10^-8).*(z-3.75*10^9))))+w   +  (w-x).*(1./(1+exp(-2*(6*10^-8).*(z-3.9*10^9))))  ');  % smooth ascent  f(rhobase,rhoup,t) (10ma)


%%%%%%% land colonisation forcing (PW2)
rough_colonisation = inline(' interp1([0 3.5e9 4e9 1e10],[0.5 0.5 1 1],x)  ') ;


%%%%%%% nutrient weathering efficiency

%%% rising steadily throughout proterozoic
% nutrient_eff = inline(' interp1([0 0.5E9 1.7E9 2.5E9 3E9],[2 0.5 0.5 0.5 0.5 1],x) ') ;

%%% rising at 800 and 400 Ma
nutrient_eff = inline(' interp1([0 0.5E9 1.7E9 2.5E9 3E9 3.7E9 3.8E9 4.1E9 4.2E9 4.5E9],[2 0.5 0.5 0.5 0.5 0.5 0.75 0.75 1 1],x) ') ;


%%%%%%% forcing to deliberately crash model (due to low O2) for analysis  %  f(base,new,t)
phos_crasher=inline('(x-w).*(1./(1+exp(-2*(6*10^-8).*(z-3*10^9))))+w   +  (w-x).*(1./(1+exp(-2*(6*10^-8).*(z-3.2*10^9))))  ');  









%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%% USER PANEL: CHOOSE FORCING FUNCTIONS AND TEMP. FUNCTION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


UPLIFT = long_combined_uplift(t);
% UPLIFT = 1;

DEGASS = Jam_squared_degassing(t);
% DEGASS = 1;

W = COPSE_W(t);
% W = 1;

EVO = COPSE_E(t);
% EVO = 1;

CPland_relative = CPlandrel(t);
% CPland_relative=1;

Bforcing = COPSE_B(t);
% Bforcing = 1;

CONTAREA = 1;
% CONTAREA = rino_contarea(t);

SOLAR = CK_solar(t)*1368;
% SOLAR = 1368;


%%% RHO, RHO2 are additional weathering enhancements  (PW1, PW2 in thesis)

% RHO = neop_runoff(1,3,t);
RHO = 1;

% RHO2 = rough_colonisation(t);
RHO2 = 1;


%%%%%%% epsilon is multiplier on nutrient weathering efficiency

EPSILON = 1;
% EPSILON = nutrient_eff(t); 
% EPSILON= prescribed_neop_phos(t) ;
% EPSILON = phos_crasher(1,0.4,t);
% EPSILON = neop_runoff(1,2,t);
% EPSILON = rough_colonisation(t);



%%%%%%% rate of input of each species from the mantle

MANTLERATE_CARBI = Jam(t);
MANTLERATE_OCC = Jam(t)^2;
MANTLERATE_PYRI = Jam(t)^2;
MANTLERATE_SUB = Jam(t)^2 ;
MANTLERATE_OXYIRON = 1;

% MANTLERATE_CARBI = 1 ;
% MANTLERATE_OCC = 1 ;
% MANTLERATE_PYRI = 1 ;
% MANTLERATE_SUB = 1 ;
% MANTLERATE_OXYIRON = 1;




%%%%%%%% calculations for pCO2, pO2
CO2atm = (y(3)/A0)*(atfrac(y(3))/atfrac(A0))*(280/1000000);
CO2atm_relative = CO2atm / (280e-6) ;
pO2 = (y(2)/O0) / ( (y(2)/O0)  +copsek16  );


%%%%%%% Temperature function:


%%% Caldeira and Kasting 1992 (with variable albedo)
% TEMP = (       (  ((1- (1.4891 - 0.0065979*y(9) + (8.567*10^-6)*(y(9)^2)  )  )*SOLAR)/(4*5.67*10^-8)  )^0.25     +  815.17  + (4.895*10^7)*(y(9)^-2) -  (3.9787*10^5)*(y(9)^-1)  -6.7084*((log10(  CO2atm  ))^-2) + 73.221*((log10(  CO2atm  ))^-1) -30882*(y(9)^-1)*((log10(  CO2atm ))^-1)     ) ;


%%%CK fixed albedo
ALBEDO = 0.3;
% TEMP = (       (  ((1- ( ALBEDO )  )*SOLAR)/(4*5.67*10^-8)  )^0.25     +  815.17  + (4.895*10^7)*(y(9)^-2) -  (3.9787*10^5)*(y(9)^-1)  -6.7084*((log10(  CO2atm  ))^-2) + 73.221*((log10(  CO2atm  ))^-1) -30882*(y(9)^-1)*((log10(  CO2atm ))^-1)     ) ;


%%%% mills2011 temp (fixed albedo)
ALBEDO = 0.3;
TEMP   =   ((   (SOLAR.*(1-ALBEDO))./(4.*(1-(0.773./2)).*5.67*10^-8)  ).^0.25)          +    0.1815.*(        0.2507.*((log10(CO2atm)).^4)  +  3.9216.*((log10(CO2atm)).^3) + 23.8113.*((log10(CO2atm)).^2) + 83.4113.*((log10(CO2atm))) + 131.6138        )   ; 






%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%% END OF USER PANEL %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%






%%%%%%% calculate fluxes



%%% fire feedback
ignit = max(586.2*(pO2)-122.102 , 0  ) ;
firef = kfire/(kfire - 1 + ignit) ;

%%% vegetation restriction
VEG = COPSE_Vnpp( EVO ,(y(2)/O0) , CO2atm*10^6 , TEMP)*firef ;


%%%%% calculate fco2, gco2 functions
fco2func = fco2(TEMP,CO2atm_relative);
gco2func = gco2(TEMP,CO2atm_relative);

%%%%%%% calculate kinetic weathering fluxes
carbw_kinetic = kcarbw*CONTAREA*UPLIFT*RHO*RHO2*(  plantenhance  + (1-plantenhance)*W*VEG  )*gco2func ;
silw_kinetic = k5*CONTAREA*UPLIFT*RHO*RHO2*(  plantenhance  + (1-plantenhance)*W*VEG  )*fco2func ;



%%%%%%% fixed transport limit
if tlimitchoice == 0

if carbw_kinetic > kcarbw*TLIMIT
    carbw = kcarbw*TLIMIT ;
else 
    carbw = carbw_kinetic ;
end

if silw_kinetic > k5*TLIMIT
    silw = k5*TLIMIT ;
else 
    silw = silw_kinetic ;
end

end


%%%%%%% dynamic transport limit
if tlimitchoice == 1

if carbw_kinetic > kcarbw*TLIMIT*UPLIFT
    carbw = kcarbw*TLIMIT*UPLIFT ;
else 
    carbw = carbw_kinetic ;
end

if silw_kinetic > k5*TLIMIT*UPLIFT
    silw = k5*TLIMIT*UPLIFT ;
else 
    silw = silw_kinetic ;
end

end



%%%%%%% other weathering fluxes

oxidw = k7*CONTAREA*UPLIFT*(y(5)/G0)*((y(2)/O0)^a) ;

pyrw = k_pyrw*CONTAREA*UPLIFT*(y(7)/PYR0)*((y(2)/O0)^a)  ;

gypw = k_gypw*(y(8)/GYP0)*(carbw/kcarbw) ;

phosw = EPSILON*k8*( (2/12)*(silw/k5)  +   (5/12)*(carbw/kcarbw) +  (5/12)*(oxidw/k7)  )  ;


%%%%%%% p delivery to land and sea
pland = k11*VEG*phosw ;
pland0 = k11*k8;
psea = phosw - pland ;



%ocean crust weathering (carbonatization)
ocw = k_hydro*MANTLERATE_OCC*( (y(3)/A0) )^alpha;




%%%%%%% mantle fluxes (i = mantle input, sub = subduction to mantle)

carbi = k_ridge*MANTLERATE_CARBI ;

pyri = k_pyrmelt*MANTLERATE_PYRI ;

ccsub = k_cd*MANTLERATE_SUB*(y(6)/C0);

ocsub = k_od*MANTLERATE_SUB*(y(5)/G0); 

pyrsub = k_pd*MANTLERATE_SUB*(y(7)/PYR0);

gypsub = k_gd*MANTLERATE_SUB*(y(8)/GYP0);

oxyiron = k_oxyiron*MANTLERATE_OXYIRON ;
% oxyiron = k_oxyiron*MANTLERATE_OXYIRON*(y(2)/O0) ;



%%%%%%% oxidised species burial
mgsb = k_gypb*(y(4)/S0) ;
mccb = carbw + silw ;



%%%%%%% degassing fluxes
ocdeg = k9*DEGASS*((y(2)/O0)^d)*(y(5)/G0) ;

ccdeg = k10*DEGASS*(y(6)/C0)*Bforcing ;

pyrdeg = k_pyrdeg*(y(7)/PYR0)*DEGASS;

gypdeg = k_gypdeg*(y(8)/GYP0)*DEGASS;



%%%%%%% burial of reduced species follows COPSE nutrient model only


%%%% marine organic carbon burial
mocb = (k1*((y(1)/P0)^b)) ;

%%%% land organic carbon burial
locb = klocb*(pland/pland0)*CPland_relative  ;

%%%% pyrite burial
mpsb = k_pyrb*(y(4)/S0)*fox(y(2))*(mocb/k1)  ;


%%%%%%%  nutrient burial 

mopb = ( (mocb)/CPsea(anox(y(2),y(1))) ) ;

capb = k2*( (mocb)/(k1 ) ) ;

fepb = (k3/k4)*(1-anox(y(2),y(1))) ;
% fepb = (k3/k4)*(1-anox(y(2),y(1)))*(  ( mocb  )/(k1) ) ;



%%%%%%% set frac factors for predictive isotope system
d_mocb = variable_d_mocb;
d_locb = variable_d_locb;
d_ocw = variable_d_ocw ;



%%%%% change dmpsb?
if mpsbfraceffect == 0
d_mpsb = variable_d_mpsb;
end

if mpsbfraceffect == 1
d_mpsb = 35*(( (y(2)/O0) )^0.1)   ;  
end

if mpsbfraceffect == 2
d_mpsb = 35*(( (y(2)/O0) )^0.5)   ;  
end


%%%%% change dmccb??
if dmccbfraceffect == 0
d_mccb = 0;
end

if dmccbfraceffect == 1
d_mccb  =   ( atfrac(y(3)) ).*( (9483./TEMP) -23.89) +15.1 -4232./TEMP  ;      
end



%%%%%%% frac factors for reservoirs 

delta_GYP  = y(16)/y(8);
delta_PYR  = y(15)/y(7);
delta_G = y(13)/y(5);
delta_C = y(14)/y(6);
delta_MPYR = variable_d_MPYR ;
delta_MC = variable_d_MC;





%%%%%%% reservoir calculations



%%% Phosphate
dy(1) = psea - mopb - capb - fepb ;
% dy(1) = 0;

%%% Oxygen
dy(2) = locb + mocb - oxidw - ocdeg + (15/8)*(mpsb - pyrw - pyrdeg)  - oxyiron  ;
% dy(2)=0;

%%% Carbon dioxide
dy(3) = -locb -mocb + oxidw + ocdeg + ccdeg + carbw - mccb - ocw + carbi  ;
% dy(3)=0;


%%% Sulphate
%%%% loop to prevent sulphate crashing during spin up for early timeframe
if t < 2.45e9 
    if t > 2.4e9
            dy(4) = 0;
    else
     dy(4) = gypw + pyrw - mgsb - mpsb + gypdeg + pyrdeg  ;
    end
    
else
   dy(4) = gypw + pyrw - mgsb - mpsb + gypdeg + pyrdeg  ;
end


    
%%% Buried pyrite S
dy(7) = mpsb - pyrw - pyrdeg -pyrsub + pyri  ;


%%% Buried gypsum S
%%%% loop to remove high buried GYP during spinup
if t < 2.45e9 
    if t > 2.4e9
            dy(8) = -1*10^11;
    else
     dy(8) = mgsb - gypw -gypdeg - gypsub ;
    end
    
else
   dy(8) = mgsb - gypw -gypdeg - gypsub ;
end

  

%%%Buried organic C
dy(5) = locb + mocb -oxidw -ocdeg - ocsub ;


%%% Buried carb C
dy(6) = mccb + ocw - carbw - ccdeg - ccsub;


%%% Iterated temperature
dy(9) = TEMP - y(9) ;



%%% predicted fractionation for hydrospheric co2, so4
delta_A = y(19)/y(3) ;    
delta_S = y(20)/y(4);



% deltaORG_C*ORG_C
dy(13) =  mocb*( delta_A - d_mocb ) +  locb*( delta_A - d_locb ) -   oxidw*delta_G     -   ocdeg*delta_G   -  ocsub*delta_G   ;

% deltaCARB_C*CARB_C
dy(14) =  mccb*( delta_A + d_mccb )   -  carbw*delta_C  -   ccdeg*delta_C    - ccsub*delta_C  +  ocw*( delta_A - d_ocw )       ;

% deltaPYR_S*PYR_S
dy(15) =  mpsb*( delta_S - d_mpsb )  - pyrw*delta_PYR   - pyrdeg*delta_PYR  -  pyrsub*delta_PYR + pyri*delta_MPYR  ;  

% deltaGYP_S*GYP_S
dy(16) =  mgsb*delta_S   - gypw*delta_GYP      - gypdeg*delta_GYP  - gypsub*delta_GYP ;

%%5 delta_A * A
dy(19) = -locb*( delta_A - d_locb ) -mocb*( delta_A - d_mocb ) + oxidw*delta_G + ocdeg*delta_G + ccdeg*delta_C + carbw*delta_C - mccb*( delta_A + d_mccb )  + carbi*delta_MC  - ocw*( delta_A - d_ocw)  ;

%%5 delta_S * S
dy(20) = gypw*delta_GYP + pyrw*delta_PYR -mgsb*delta_S - mpsb*( delta_S - d_mpsb ) +gypdeg*delta_GYP + pyrdeg*delta_PYR ;





%%%%% mantle reservoirs 


%%%% mantle ORG carbon
dy(26) = ocsub ;
%%%% mantle CARB carbon
dy(27) = ccsub - carbi  ;
%%%% mantle PYR sulphur
dy(28) = pyrsub - pyri ;
%%%% mantle GYP sulphur
dy(29) = gypsub ;


%%%%% change in fractionation effect for pyr and carb
dy(41) = d_mpsb - y(41) ;
dy(47) = d_mocb - y(47) ;
dy(48) = d_mccb - y(48) ;


%%%% gypsum burial for 's' ratio
dy(42) = mgsb - y(42) ;





%%%%%%% track size of important variables

dy(10) = mocb - y(10) ;
dy(11) = locb - y(11)  ;
dy(12) = mpsb - y(12)  ;

dy(17)  =  pO2 - y(17) ;
dy(18) = CO2atm - y(18) ;

dy(21) = anox(y(2),y(1)) - y(21) ;
dy(22) = W - y(22) ;
dy(23) = EPSILON - y(23) ;
dy(24) = CONTAREA - y(24) ;
dy(25) = RHO - y(25);

dy(30) = UPLIFT - y(30) ;
dy(31) = DEGASS - y(31) ;
dy(32) = SOLAR - y(32) ;
dy(33) = mccb - y(33) ;
dy(34) = pyrsub - y(34) ;
dy(35) = ccsub - y(35)  ;
dy(36) = MANTLERATE_CARBI - y(36) ;
dy(37) = ocw - y(37) ;
dy(38) =  mopb - y(38) ;
dy(39) =  capb - y(39) ;
dy(40) =  fepb - y(40) ;

dy(43) = silw - y(43) ;
dy(44) = carbw - y(44) ;
dy(45) = phosw - y(45) ;
dy(46) =  0 ;

dy(49) = RHO2 - y(49) ; 
dy(50) = ccdeg - y(50) ;
dy(51) = carbi - y(51) ;
dy(52) = oxidw - y(52) ; 
dy(53) = ocdeg - y(53) ;



if telltime ==1
t
end

end
