%%%%%%% Mantle Model: PhD thesis version.
%%%%%%% Benjamin Mills. Dec 2012. benjaminmills@live.com
%%%%%%%
%%%%%%% Extension of Minimal Model -
%%%%%%% additional fluxes added to represent inputs from the mantle,
%%%%%%% subduction to the mantle, and carbonatization of ocean crust.
%%%%%%% 
%%%%%%% 
%%%%%%% Model frontend
%%%%%%%
%%%%%%% User panel line 140



%%%%%%% set up global parameters


clear all
global telltime
global k1
global k2
global k3
global k4
global k5
global k7
global k8
global k9
global k10
global a
global b
global d
global rp
global k_pyrb
global k_gypb
global P0
global O0
global A0
global G0
global C0
global Q0
global PYR0
global GYP0
global S0
global M0
global alpha
global variable_d_ocw
global variable_d_mocb
global variable_d_locb
global rv
global kcarbw
global graphsplease
global k11
global klocb
global kfire
global copsek16
global k_pyrdeg
global k_gypdeg
global k_pyrw
global k_gypw
global plantenhance
global k_ridge
global k_pyrmelt
global k_hydro
global k_od
global k_cd
global k_pd
global k_gd
global variable_d_mpsb
global variable_d_MPYR 
global variable_d_MC
global k_oxyiron
global dmccbfraceffect
global mpsbfraceffect
global TLIMIT
global tlimitchoice
global conservationcheck
global showtimetaken

%%%%%%% model constants


%reservoir present day sizes
P0=3.1*10^15;
O0=3.7*10^19;
A0=3.193*10^18;
Q0=1.3*10^20;
PYR0=1.8*10^20;
GYP0=2*10^20;
S0=4*10^19;
M0=10^14;

%%%hayes and waldbaur 2006
G0=1.275*10^21;
C0=7.225*10^21;


%%%%%%% CO2 ridge input and hydrothermal carbonatization
k_hydro = 1.65*10^12 ;
k_ridge = 2.2*10^12 ;

%%%%%%% subduction fluxes
k_od = 1.8*10^11 ;
k_cd = 1.02*10^12 ;
k_pd = 3.6*10^11 ;
k_gd = 4*10^11 ;

%%%%%%% use copse papers mocb + locb
k1 = 4.5*10^12;  
klocb = 4.5*10^12 ;

%%%%%%% sulphur weathering/degassing
k_pyrdeg = 0.25*10^12; 
k_gypdeg = 0.5*10^12;

%%%%%%% allow some consumption of O2 via reduced iron input?
k_oxyiron = 0 ;

%%% other constants
kcarbw=13.35*10^12;
k2=1.5*10^10;
k3=6*10^9;
k4=0.86;
k9=1.25*10^12;
k10=6.65*10^12;
k11 = 0.10345;
kfire= 100;

%COPSE constant for calculating pO2 from normalised O2
copsek16=3.762;

% R_PDB
rp=0.0112372;

% R_VCDT
rv=0.04416376;




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% USER PANEL %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%% basic dependencies
a=0.5; %oxidative weathering dependency on O2 concentration
b=2; %marine organic carbon burial dependency on new production
d=0; %organic carbon degassing dependency on O2 concentration

%%%%%%% weathering enhancement factor prior to vascular plant colonisation
plantenhance = 1/4;


%%%%%%% transport limitation of weathering. 0 = fixed limit, 1 = rate
%%%%%%% scales with global erosion/uplift rate
tlimitchoice = 0;

%%%%%%% define maximum weathering rate relative to prsent day (k_transport)
TLIMIT = 2.4 ;


%%%%% alpha is dependency of ocean crust carbonatization on CO2
alpha=0.23; %%% bradley and gislason 1997 (used in sleep and zahnle 2001)
% alpha = 0;
% alpha = 0.3;
% alpha=0.4;


%%%% fractionation effects for fluxes, (define as +ve)
variable_d_ocw = 0;
variable_d_mocb = 27 ;
variable_d_locb = 27 ;
variable_d_mpsb = 40 ;
%%%% fractionation of mantle pyrite and carbon
variable_d_MPYR = 2 ;
variable_d_MC = -5 ;



%%%%%%% have temp/atfrac based fractionation on mccb?? 1=yes, 0 = no.
dmccbfraceffect = 0 ;

%%%%%%% have GEOCARB style effect on mpsb fractionation? 1 = ^(0.1), 2 =
%%%%%%% ^(0.5), 0 = none.
mpsbfraceffect = 0 ;


%%%%%%% model timeframe in years (4.5e9 = present day)
whenstart=2.35*10^9;
whenend=4.5*10^9;


%%%%%%% set maximum step size for solver
options = odeset('maxstep',10^6) ;


%%%% starting resevoir sizes for phanerozoic run 

% gstart=G0*1;
% cstart=C0*1;
% pstart=P0;
% ostart=O0*0.5;
% astart=A0*15;
% pyrstart=PYR0*1;
% gypstart=GYP0*1;
% sstart=S0*1;
% tempstart=288;


%%%% starting sizes for proterozoic run
gstart=G0*0.65;
cstart = C0*0.65;
pstart=P0*0.5;
ostart=O0*0.5;
astart=A0*10;
pyrstart=PYR0*2;
gypstart=GYP0*0.05;
sstart=S0*0.1;
tempstart=288;


%%%% starting isotopic values (stability)
delta_G_start = -24 ;
delta_PYR_start = 2 ;
delta_C_start = -3;
delta_GYP_start = 2;
delta_A_start = -3;
delta_S_start = 2;


%%% starting isotopic values (assuming buffered reservoirs)
 % delta_G_start = -27 ;
% delta_PYR_start = 2 ;
% delta_C_start = 0.01;
% delta_GYP_start = 2;
% delta_A_start = 0.01;
% delta_S_start = 2;



%%%%%%% Show current timestep in command window? (1 = yes, 0 = no)
telltime = 1;


%%%%%%% output how long the run has taken? (1 = yes, 0 = no)
showtimetaken = 1;

%%%%%%% display change in model total carbon during run? (1 = yes, 0 = no)
conservationcheck = 1;


%%%%%%% Show output graphs? (1 = yes, 0 = no)
graphsplease = 1;


%%% plot over the top of old graphs?
plotovertop = 0;
%%% plot over which graphs
whichplotover_1 = 1;
whichplotover_2 = 2;


%%% save the output?
saveoutput = 0;
%%% prefix for saving results graphs
pathname = 'OUTPUT\20nov2012\' ;
prefix =  'example_prefix_' ;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%% END OF USER PANEL%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%









%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% calculate unknowns for present day steady state
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%% define burial fluxes
k_pyrb = 1*10^12;
k_gypb = 2*10^12;


%%%%%%% calculate unknowns by assuming S steady state
k_gypw  = - k_gd - k_gypdeg +k_gypb ;
k_pyrw   = k_pyrb - k_pyrdeg + k_gd;
k_pyrmelt = k_gd + k_pd ;

%%% oxygen steady calc for k7
k7 = klocb + k1 - k9 + (15/8)*(k_pyrb - k_pyrw - k_pyrdeg) - k_oxyiron ;

%%% A steady calc for k5
k5 = -k1 -klocb + k7 + k9 + k10 + k_ridge - k_hydro  ;

%%% phos calc for k8
k8 = ( k1/250  +k2 +k3 )  / (1-k11) ;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%% when did this run start?
usertime_start = fix(clock) ;


%%%%%%% run the system
[T,Y] = ode15s(@mantle_equations,[whenstart whenend],[pstart ostart astart sstart gstart cstart pyrstart gypstart tempstart 0 0 0  gstart*delta_G_start     cstart*delta_C_start     pyrstart*delta_PYR_start    gypstart*delta_GYP_start  0.21 0.00028 astart*delta_A_start sstart*delta_S_start 0.14 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 35 0 0 0 0 0 0 0 0 0 0 0 0],options);







%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% PLOT RESULTS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


A=size(Y);
w=A(1);

if graphsplease == 1

    
%%%%%%% import data for comparisons, defined here as inline function    

  

    f_shieldsveizercarbonate = inline('interp1([703873600	1074923500	1091233400	1148318000	1160550500	1429663600	1596840000	1604994900	1653924600	1698776800	1706931700	1743629000	1759938800	1788481100	1804791000	1825178400	1857798200	1874108100	1894495400	1939347600	1951580000	1971967400	1980122300	1992354700	2004587200	2065749200	2073904200	2094291500	2106524000	2143221200	2155453600	2196228300	2208460800	2245158000	2253312900	2294087700	2306320100	2334862400	2351172300	2396024500	2408256900	2428644200	2449031600	2457186500	2481651400	2502038700	2514271200	2575433200	2595820600	2689602400	2791539200	2811926600	2889398600	2909785900	3007645300	3036187600	3072884800	3097349600	3142201800	3154434300	3187054000	3207441400	3305300700	3407237500	3431702300	3456167200	3492864400	3549949000	3578491300	3631498500	3668195700	3684505600	3692660600	3708970400	3725280300	3745667700	3753822600	3770132500	3786442400	3798674800	3823139700	3843527000	3851682000	3863914400	3884301700	3900611600	3912844000	3929153900	3949541300],[0.1010101	0.1010101	-0.1010101	-0.2020202	-0.25252525	-0.35353535	-0.50505051	-0.85858586	-0.85858586	-1.0606061	-1.4141414	-1.4141414	-0.25252525	0.050505051	-0.2020202	-0.050505051	2.48933E-16	0.2020202	0.3030303	0.2020202	0.60606061	0.80808081	1.2626263	1.4646465	1.7676768	2.0707071	2.5252525	2.6767677	3.4848485	3.5353535	3.3333333	3.4343434	2.6767677	2.4242424	2.1717172	2.5252525	3.7878788	3.8888889	3.6363636	3.5858586	4.5959596	3.7878788	2.9292929	1.5151515	0.90909091	0.85858586	0.3030303	0.15151515	-0.1010101	-0.3030303	-0.3030303	-0.55555556	-0.65656566	-0.45454545	-0.45454545	-0.35353535	0.050505051	0.35353535	0.4040404	1.3131313	1.5151515	1.3636364	1.5151515	1.7171717	1.5656566	1.2626263	1.0606061	0.95959596	0.75757576	0.65656566	0.90909091	1.2121212	3.2323232	3.5353535	3.5353535	3.7878788	1.2121212	1.0606061	1.3131313	3.2323232	3.1818182	3.3333333	0.25252525	0.45454545	0.15151515	-0.50505051	0.15151515	-0.85858586	-0.2020202],x)') ;
        f_veizerphancarbonate = inline('interp1([3942728400	3955515100	3979926000	3984575700	3990969000	3996781100	4000268400	4002012100	4006080500	4009567800	4013636300	4021773300	4026423000	4032235100	4038047200	4041534500	4044440500	4046765400	4053158700	4055483600	4058389600	4062458100	4067107800	4071757500	4076407200	4081056900	4084544200	4094424800	4097912100	4100818100	4106630300	4110698700	4114767200	4120579300	4124647800	4126972700	4131041200	4138015700	4142665400	4144990300	4149058700	4153708400	4158358100	4160683000	4165913900	4171144800	4176375700	4178700600	4181025400	4185093900	4189162400	4192649700	4196718100	4201949100	4208342400	4212410900	4215316900	4218223000	4221710300	4225778800	4228103600	4229266000	4231590900	4235078200	4237403000	4239727900	4242633900	4245540000	4248446000	4251933300	4254258200	4257745400	4260070300	4261813900	4264720000	4266463600	4271113300	4272856900	4276925400	4279831500	4282156300	4285062400	4288549700	4295524200	4299592700	4303080000	4310054500	4312960600	4315285400	4317029100	4320516300	4324584800	4328072100	4330397000	4332140600	4333303000	4334465400	4337952700	4343183600	4346089700	4351320600	4353645400	4355970300	4360038800	4364688500	4369919400	4375150300	4379800000	4383868500	4387355800	4390261800	4392586700	4396073900	4401886100	4407117000	4410604200	4414672700	4416997600	4419903600	4422809700	4430946700	4433852700	4438502400	4444314500	4447801800	4454195200	4461750900	4469887900	4475700000	4482093300	4487324200	4489649100	4492555200	4499529700],[-0.83121597	-0.86025408	-0.076225045	-0.01814882	-0.16333938	-0.30852995	-1.092559	-1.3248639	-1.092559	-1.092559	-1.1796733	-1.2667877	-1.0635209	-1.0635209	-0.74410163	-0.22141561	-0.13430127	-0.13430127	0.2722323	0.99818512	1.4047187	1.6660617	1.6079855	1.6660617	1.5208711	1.9854809	2.1016334	2.9727768	2.6823956	1.753176	0.91107078	0.96914701	0.79491833	0.67876588	0.79491833	0.91107078	0.88203267	1.5789474	2.3629764	2.7404719	2.9437387	3.0018149	2.8275862	2.5662432	2.5952813	2.7404719	3.0598911	3.5825771	4.076225	4.3375681	4.5117967	4.3956443	4.1343013	3.9600726	3.814882	3.7568058	3.814882	3.9891107	3.9600726	3.3793103	3.0598911	2.9437387	2.9437387	3.4664247	3.9310345	4.2504537	4.2794918	4.0181488	3.9019964	3.4083485	2.76951	2.0725953	1.6079855	1.5499093	1.6370236	1.753176	1.8983666	2.6533575	3.2341198	3.292196	2.6243194	1.8402904	1.7241379	1.7241379	1.6079855	1.6079855	1.8693285	1.8693285	1.8112523	2.0145191	2.0725953	1.753176	1.1724138	0.91107078	1.1724138	1.6079855	2.3339383	2.3629764	1.9274047	1.7241379	1.6370236	1.1724138	0.88203267	0.79491833	0.91107078	0.94010889	1.3466425	1.3756806	2.7985481	3.292196	3.2050817	2.3049002	1.491833	1.4047187	1.2014519	1.2014519	1.6079855	1.6660617	1.4337568	1.4627949	1.7822142	2.1887477	2.2177858	2.76951	2.7404719	2.0145191	1.6370236	1.4047187	1.7822142	2.1016334	1.8983666	1.491833	1.3756806	1.3756806],x)') ;
            f_canfieldsulphate_upperline = inline('interp1([1052689800	1795764700	2212796500	2899003400	3096145700	3198508100	3251584900	3316035200	3342573600	3399441600	3494221600	3554880700	3604166300	3657243100	3706528700	3759605500	3835429400	3873341400	3918835800	3952956600	3971912600	4002242200	4013615800	4032571700	4051527700	4062901300	4081857300	4089439700	4112186900	4131142900	4150098900	4172846100	4191802100	4195593300	4206966900	4222131700	4252461300	4271417300	4290373200	4305538000	4328285200	4335867600	4362406000	4385153200	4396526800	4415482800	4434438800	4453394800	4464768400	4479933200	4498889200	4506471600],[5.6934307	10.620438	17.919708	22.846715	18.284672	17.919708	20.291971	20.474453	21.021898	21.20438	25.766423	25.766423	21.569343	20.474453	20.474453	22.481752	28.50365	30.693431	32.335766	32.70073	31.058394	32.335766	26.678832	25.583942	26.313869	27.773723	26.861314	27.773723	26.313869	24.124088	27.408759	20.656934	19.927007	17.007299	16.459854	16.824818	13.722628	14.270073	20.656934	18.649635	19.927007	19.19708	19.744526	19.014599	17.554745	20.109489	20.109489	20.839416	20.474453	25.218978	24.489051	22.664234],x)') ;
    
    
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
%%% FIRST FIGURE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



if plotovertop == 1
    figure(whichplotover_1)
else
    figgy1 = figure('Color',[1 1 1]) ;
end
    


%%% model forcings %%%%%%%%%%
subplot(3,3,1,'LineWidth',1)
box('on');
xlim([whenstart whenend])
hold on

plot(T,Y(:,22),'g','LineWidth',2)
plot(T,Y(:,23),'c','LineWidth',2)
plot(T,Y(:,24),'k','LineWidth',2)
plot(T,Y(:,25),'r','LineWidth',2)
plot(T,Y(:,30),'b--','LineWidth',2)
plot(T,Y(:,31),'k--','LineWidth',2)
plot(T,Y(:,32)./1368,'y-','LineWidth',2)
plot(T,Y(:,36),'m','LineWidth',2)
plot(T,Y(:,49),'r--','LineWidth',2)

ylabel('Forcings')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%% O2 %%%%%%%%%%%%%%%%%%%%%%
subplot(3,3,2,'LineWidth',1)
box('on');
xlim([whenstart whenend])
hold on

semilogy([whenstart whenend],[1 1],'LineWidth',1,'Color',[0.8314 0.8157 0.7843])
semilogy([whenstart whenend],[0.1 0.1],'LineWidth',1,'Color',[0.8314 0.8157 0.7843])
semilogy(T, Y(:,17)./0.21,'k','LineWidth',2)

ylabel('RO_{2}')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%% CO2 %%%%%%%%%%%%%%%%%%%%%
subplot(3,3,3,'LineWidth',1)
box('on');
xlim([whenstart whenend])
hold on

plot([whenstart whenend],[1 1],'LineWidth',1,'Color',[0.8314 0.8157 0.7843])
plot(T, Y(:,18)./(280e-6),'k','LineWidth',2)

ylabel('RCO_{2}')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%% Temperature %%%%%%%%%%%%
subplot(3,3,4,'LineWidth',1)
box('on');
xlim([whenstart whenend])
hold on

plot(T, Y(:,9) - 273.15 ,'k','LineWidth',2)

ylabel('Temperature (C)')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%% Nutrient %%%%%%%%%%%%%%
subplot(3,3,5,'LineWidth',1)
box('on');
xlim([whenstart whenend])
hold on

plot(T,Y(:,1),'k','LineWidth',2)

ylabel('Phosphate (mol)')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%% C burial rates %%%%%%%%
subplot(3,3,6,'LineWidth',1)
box('on');
xlim([whenstart whenend])
hold on

plot(T,Y(:,10),'LineWidth',2,'Color',[0.8314 0.8157 0.7843])
plot(T,Y(:,11),'k','LineWidth',2)
plot(T,Y(:,11)+Y(:,10),'k--','LineWidth',2)

ylabel({'C burial (mol/yr)';'grey:marine,black:land,dashed:total'})
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%% 'f' ratio %%%%%%%%%%%%%%%
subplot(3,3,7,'LineWidth',1)
box('on');
xlim([whenstart whenend])
hold on

plot(T,( Y(:,11)+Y(:,10) )./ ( Y(:,11) + Y(:,10) +  Y(:,33) + Y(:,37)  + Y(:,46)  ),'k','LineWidth',2)
plot(T,( Y(:,12) )./ ( Y(:,12) + Y(:,42)   ),'b','LineWidth',2)

ylabel('f-ratio (k), s-ratio (b)')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%% d13C carb %%%%%%%%%%%%%%
subplot(3,3,8,'LineWidth',1)
box('on');
xlim([whenstart whenend])
hold on

%%%% plot data to compare
plot(T,f_shieldsveizercarbonate(T),'LineWidth',5,'Color',[0.8314 0.8157 0.7843])
plot(T,f_veizerphancarbonate(T),'LineWidth',5,'Color',[0.8314 0.8157 0.7843])

%%% d13C of new carbonate = d13c(atm/ocean carbon) + frac effect on burial
plot(T,  (   Y(:,19)./Y(:,3)  )   +   Y(:,48) ,'k','LineWidth',2)

ylabel({'\delta^{13}C carb';'grey:shields and veizer'})
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%% d34S gyp %%%%%%%%%%%%%%%
subplot(3,3,9,'LineWidth',1)
box('on');
xlim([whenstart whenend])
hold on

%%%% plot data to compare
plot(T,f_canfieldsulphate_upperline(T),'LineWidth',5,'Color',[0.8314 0.8157 0.7843])
plot(T,f_canfieldsulphate_upperline(T) - 5 ,'LineWidth',5,'Color',[0.8314 0.8157 0.7843])
%%%% model output
%%%% frac of new gyp
plot(T,Y(:,20)./Y(:,4),'k','LineWidth',2)
%%%% frac of new pyrite
plot(T,( Y(:,20)./Y(:,4) ) - Y(:,41) ,'k--','LineWidth',2)


ylabel({'\delta^{34}S gyp';'grey:canfield'})
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%% save this graph
if saveoutput == 1
    thisgraph = '_fig1' ;
    filename = [pathname prefix thisgraph];
    saveas(figgy1,filename,'fig'); 
end






%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%% SECCOND FIGURE %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



if plotovertop == 1
    figure(whichplotover_2)
else
    figgy2 = figure('Color',[1 1 1]) ;
end
    


%%% weathering fluxes %%%%%%%%%%
subplot(3,3,1,'LineWidth',1)
box('on');
xlim([whenstart whenend])
hold on

plot(T,Y(:,43)./k5,'r','LineWidth',2)
plot(T,Y(:,44)./kcarbw,'c','LineWidth',2)
plot(T,Y(:,45)./k8,'b','LineWidth',2)


ylabel({'relative weathering fluxes';'r:silw,c:carbw,b:phosw'})
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%% S  reservoirs %%%%%%%%%%%%%%%%%%%%%%
subplot(3,3,2,'LineWidth',1)
box('on');

semilogy(T,Y(:,4)./S0,'r','LineWidth',2)
hold on
semilogy(T,Y(:,7)./PYR0,'k','LineWidth',2)
semilogy(T,Y(:,8)./GYP0,'c','LineWidth',2)

xlim([whenstart whenend])
ylim([0.001 10])
ylabel({'relative S reservoirs';'r:SO4,k:PYR,c:GYP'})
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%% C reservoirs %%%%%%%%%%%%%%%%%%%%%
subplot(3,3,3,'LineWidth',1)
box('on');

%%%% plot the total crustal C
hold on
semilogy(T,Y(:,5) + Y(:,6),'k','LineWidth',2)


xlim([whenstart whenend])
ylim([1e21 9e21])
ylabel('total crustal C (mol)')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%% Pyr burial %%%%%%%%%%%%
subplot(3,3,4,'LineWidth',1)
box('on');
xlim([whenstart whenend])
hold on

plot(T,Y(:,12),'k','LineWidth',2)

ylabel('Pyrite burial (mol/yr)')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%% C isotope system %%%%%%%%%%%%%%
subplot(3,3,5,'LineWidth',1)
box('on');
xlim([whenstart whenend])
hold on

plot(T,Y(:,19)./Y(:,3),'r.','LineWidth',2)
plot(T,Y(:,13)./Y(:,5),'k.','LineWidth',2)
plot(T,Y(:,14)./Y(:,6),'c.','LineWidth',2)

ylabel({'C fractionation';'r:CO2,c:C,k:G'})
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%% S isotope system %%%%%%%%
subplot(3,3,6,'LineWidth',1)
box('on');
xlim([whenstart whenend])
hold on

plot(T,Y(:,20)./Y(:,4),'r.','LineWidth',2)
plot(T,( Y(:,20)./Y(:,4) ) - Y(:,41) ,'r--','LineWidth',2)
plot(T,Y(:,15)./Y(:,7),'k.','LineWidth',2)
plot(T,Y(:,16)./Y(:,8),'c.','LineWidth',2)

ylabel({'S fractionation';'r:SO4,c:GYP,k:PYR'})
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%% 'anox' variable %%%%%%%%%%%%%%%
subplot(3,3,7,'LineWidth',1)
box('on');
xlim([whenstart whenend])
hold on

plot(T,Y(:,21),'k','linewidth',2)

ylabel('Anoxic frac')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




%%%% Average fractionation of surface reservoirs %%%%%%%%
subplot(3,3,8,'LineWidth',1)
box('on');
xlim([whenstart whenend])
hold on

plot( T, ( Y(:,19)+Y(:,14)+Y(:,13) )./ (Y(:,3)+Y(:,5)+Y(:,6)) , 'k')
plot( T, ( Y(:,20)+Y(:,15)+Y(:,16) )./ (Y(:,4)+Y(:,7)+Y(:,8)) , 'b')


ylabel('Average fractionation of global C(b), S(k)')
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%% plot the different C burial rates, and total C burial rate.
subplot(3,3,9,'LineWidth',1)
box('on');
xlim([whenstart whenend])
hold on

plot(T, Y(:,10)+Y(:,11) ,'k','LineWidth',2)
plot(T, Y(:,33) ,'c','LineWidth',2)
plot(T, Y(:,37) ,'r','LineWidth',2)
plot(T, Y(:,10)+Y(:,11)+Y(:,33)+Y(:,37), 'k--', 'linewidth',2)


%%%% plot total degassing
plot(T, Y(:,44)+Y(:,53)+Y(:,50)+Y(:,51)+Y(:,52), 'c--', 'linewidth',2)

ylabel({'C burial rates: k:organic,c:mccb,r:occ';'k-:total burial, c-:total degassing'})





%%%% save this graph
if saveoutput == 1
    thisgraph = '_fig1' ;
    filename = [pathname prefix thisgraph];
    saveas(figgy1,filename,'fig'); 
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


end







%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% additional outputs to command window
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



% % MASS CONSERVATION CHECKS

if conservationcheck==1
    Carbon_conservation =(Y(A(1),3)+Y(A(1),5)+Y(A(1),6)+Y(A(1),26)+Y(A(1),27)  -(Y(1,3)+Y(1,5)+Y(1,6))+Y(1,26)+Y(1,27)) 
    Sulphur_conservation = (Y(A(1),4)+Y(A(1),7)+Y(A(1),8)+Y(A(1),28)+Y(A(1),29)  -(Y(1,4)+Y(1,7)+Y(1,8))+Y(1,28)+Y(1,29)) 
end


%%%%%%% how long did the run take?
usertime_end = fix(clock) ;

if showtimetaken == 1
time_taken_vector =  usertime_end - usertime_start  ;
time_taken_mins = sum(time_taken_vector .* [12*30*24*60 30*24*60 24*60 60 1 (1/60)])
end





