%%%%%%% Minimal Model PhD thesis final version (v1.1)
%%%%%%% Benjamin Mills. Dec 2012. benjaminmills@live.com
%%%%%%%
%%%%%%% Main thesis model - simplified modular framework based on
%%%%%%% the GEOCARB/COPSE models.
%%%%%%% 
%%%%%%% Model frontend
%%%%%%%
%%%%%%% User panel line 110


%%%%%%% set up global parameters

clear all
global dmocb
global telltime
global k1
global k2
global k3
global k4
global k5
global k7
global k8
global k9
global k10
global a
global b
global d
global rp
global k21
global k22
global P0
global O0
global A0
global G0
global C0
global Q0
global PYR0
global GYP0
global S0
global M0
global rv
global dpyrb
global kcarbw
global graphsplease
global k11
global klocb
global kfire
global copsek16
global isotopeforcing
global k_pyrdeg
global k_gypdeg
global k_pyrw
global k_gypw
global plantenhance
global TLIMIT
global tlimitchoice
global o2fix
global conservationcheck

%%%%%%% model constants


%%%%% sulphur weathering/degassing, grom GEOCARBSULFvolc code
k_pyrw = 0.45*10^12;
k_gypw = 2*10^12;
k_pyrdeg = 0.25*10^12; 
k_gypdeg = 0.5*10^12;

%%%%% burial of pyr, gyp
k21=0.7*10^12;
k22=2.5*10^12;

%%%%% additional constants (see documentation)
kcarbw=13.35*10^12;
k2=1.5*10^10;
k3=6*10^9;
k4=0.86;
k9=1.25*10^12;
k10=6.65*10^12;
k11 = 0.10345;

%COPSE constant for calculating pO2 from normalised O2
copsek16=3.762;

% R_PDB
rp=0.0112372;
dmocb=-30;

% R_VCDT
rv=0.04416376;
dpyrb=-35;

%reservoir present day sizes (mol)
P0=3.1*10^15;
O0=3.7*10^19;
A0=3.193*10^18;
G0=1.25*10^21;
C0=5*10^21;
Q0=1.3*10^20;
PYR0=1.8*10^20;
GYP0=2*10^20;
S0=4*10^19;
M0=10^14;





%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%% USER PANEL
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%% choose isotope forcing (GEOCARB, 1) or nutrient system (COPSE, 0) for
%%%%%%% burial of organic carbon and pyrite sulphur.
isotopeforcing = 0 ;

%%%%%%% option to hold oxygen constant, 1 = fix O2, 0 = do not fix O2.
o2fix = 0;

%%%%%%% basic dependencies
a=0.5; %oxidative weathering dependency on O2 concentration
b=2; %marine organic carbon burial dependency on new production
d=0; %organic carbon degassing dependency on O2 concentration

%%%%%%% weathering enhancement factor prior to vascular plant colonisation
plantenhance = 1/4;

%%%%%%% transport limitation of weathering. 0 = fixed limit, 1 = rate
%%%%%%% scales with global erosion/uplift rate
tlimitchoice = 0;

%%%%%%% define maximum weathering rate relative to prsent day (k_transport)
TLIMIT = 2.4 ;


%%%%%%% model timeframe in years (4.5e9 = present day)
whenstart=3.95*10^9;
whenend=4.5*10^9;


%%%%%%% set maximum step size for solver
options = odeset('maxstep',10^6) ;


%%%%%%% set starting reservoir sizes
gstart=G0;
cstart=C0;
pstart=P0;
ostart=O0;
% ostart=O0*0.04;
astart=A0;
pyrstart=PYR0;
gypstart=GYP0;
sstart=S0;
tempstart=288;


%%%%%%% Show output graphs? (1 = yes, 0 = no)
graphsplease = 1;

%%%%%%% Show current timestep in command window? (1 = yes, 0 = no)
telltime = 1;

%%%%%%% display change in model total carbon during run? (1 = yes, 0 = no)
conservationcheck = 1;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%% END OF USER PANEL
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%





%%%%% COPSE
if isotopeforcing == 0
k1=4.5*10^12;   
klocb = 4.5*10^12 ;
end

%%fire feedback
kfire= 100;


%%%%% GEOCARB
if isotopeforcing ==1
k1 =   5.5e+012;
klocb=0;
end


%%% starting isotopic values for reservoirs (as in GEOCARB)

delta_G_start = -23.5 ;

delta_C_start =  ( -3.5*(G0 + C0) - delta_G_start*G0 ) / C0 ;

delta_PYR_start = -10 ;

delta_GYP_start =  ( 4*(PYR0 + GYP0) -  delta_PYR_start*PYR0 )/GYP0 ;


%%% starting values for COPSE isotope system
delta_A_start = 0;

delta_S_start = 35;



%%%%%%% calculate unknowns assuming present day steady state

%%% G calc for k7
k7= k1 + klocb -k9  ;

%%% A calc for k5
k5 = -k1 -klocb + k7 + k9 + k10 ;

%%% P calc for k8
k8 = ( k1/250  +k2 +k3 )  / (1-k11) ;




%%%%%%% run the system
[T,Y] = ode15s(@minimal_equations,[whenstart whenend],[pstart ostart astart sstart gstart cstart pyrstart gypstart tempstart 0 0 0  gstart*delta_G_start     cstart*delta_C_start     pyrstart*delta_PYR_start    gypstart*delta_GYP_start  0.21 0.00028 astart*delta_A_start sstart*delta_S_start 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 1],options);




%%%%%%% plot results

A=size(Y);
w=A(1);
if graphsplease == 1
 simplefiggy1 = figure('Color',[1 1 1]) ;


subplot(3,5,1);
plot(T,Y(:,17)./(0.21))
hold on
title('RO2','FontWeight','bold')
xlim([whenstart whenend])
ylabel('Relative conc.')


subplot(3,5,2);
plot(T,Y(:,18)./(280/1000000))
hold on
title('RCO2','FontWeight','bold')
xlim([whenstart whenend])
ylabel('Relative conc.')


subplot(3,5,3);
plot (T, Y(:,9)-273.15,'displayname','temp')
hold on
title('Temperature (C)','FontWeight','bold')
xlim([whenstart whenend])
ylabel('Temp (C)')


subplot(3,5,4);
semilogy(T,Y(:,1));
title('Ocean phosphate (mol)','FontWeight','bold')
xlim([whenstart whenend])
hold on
ylabel('mol')

subplot(3,5,5);
hold on
plot(T,Y(:,34)./k5,'r','LineWidth',2)
plot(T,Y(:,35)./kcarbw,'c','LineWidth',2)
plot(T,Y(:,36)./k8,'b','LineWidth',2)
title('relative weathering fluxes','FontWeight','bold')
xlim([whenstart whenend])
ylabel('Relative flux')


subplot(3,5,6)
semilogy(T,Y(:,4)./S0,'b','displayname','S')
hold on
title({'relative S abundances (log)';'r:PYR, b:SO4, c:GYP'},'FontWeight','bold')
semilogy(T,Y(:,7)./PYR0,'r','displayname','PYR')
semilogy(T,Y(:,8)./GYP0,'c','displayname','GYP')
xlim([whenstart whenend])
ylabel('Relative abundance')


subplot(3,5,7)
plot(T,Y(:,4)./S0,'b','displayname','S')
hold on
title({'relative S abundances';'r:PYR, b:SO4, c:GYP'},'FontWeight','bold')
plot(T,Y(:,7)./PYR0,'r','displayname','PYR')
plot(T,Y(:,8)./GYP0,'c','displayname','GYP')
xlim([whenstart whenend])
ylabel('Relative abundance')


subplot(3,5,8)
semilogy(T,Y(:,5)./G0,'c','displayname','G')
hold on
title({'relative C abundances (log)';'r:CO2, c:C, k:G'},'FontWeight','bold')
semilogy(T,Y(:,6)./C0,'k','displayname','C')
semilogy(T,Y(:,3)./A0,'r','displayname','A')
xlim([whenstart whenend])
ylabel('Relative abundance')

subplot(3,5,9)
plot(T,Y(:,5)./G0,'c','displayname','G')
hold on
title({'relative crustal C abundances (log)';'c:C, k:G, g-:total'},'FontWeight','bold')
plot(T,Y(:,6)./C0,'k','displayname','C')
plot(T, ( Y(:,5)+Y(:,6) )./ (G0 + C0) , 'g-.')
xlim([whenstart whenend])
ylabel('Relative abundance')

subplot(3,5,10);
plot(T,Y(:,10),'b')
hold on
plot(T,Y(:,11),'k')
plot(T,Y(:,11)+Y(:,10),'k--')
title({'org-C burial (mol/yr)';'b:marine, k:land, k-:total'},'FontWeight','bold')
xlim([whenstart whenend])
ylabel('Burial rate')

subplot(3,5,11);
plot(T,( Y(:,11)+Y(:,10) )./ ( Y(:,11) + Y(:,10) +  Y(:,33)  ))
hold on
title('f-ratio','FontWeight','bold')
xlim([whenstart whenend])


subplot(3,5,12)
plot(T,Y(:,12),'k')
hold on
xlim([whenstart whenend])
ylim([0 3*10^12])
title('Pyrite S burial (mol/yr)','FontWeight','bold')
ylabel('Burial rate')

subplot(3,5,13)
plot(T,Y(:,19)./Y(:,3),'r.')
hold on
plot(T,Y(:,14)./Y(:,6),'c.')
plot(T,Y(:,13)./Y(:,5),'k.')
xlim([whenstart whenend])
title('d13C. c:C,k:G,r:CO2','FontWeight','bold')
ylabel('per mille')

subplot(3,5,14)
plot(T,Y(:,20)./Y(:,4),'r.')
hold on
plot(T,Y(:,16)./Y(:,8),'c.')
plot(T,Y(:,15)./Y(:,7),'k.')
xlim([whenstart whenend])
title('d34S. c:GYP,k:PYR,r:SO4','FontWeight','bold')
ylabel('per mille')

subplot(3,5,15)
plot(T,Y(:,22),'g')
hold on
plot(T,Y(:,23),'c')
plot(T,Y(:,24),'k') 
plot(T,Y(:,25),'r')
plot(T,Y(:,30),'b--')
plot(T,Y(:,31),'k--')
plot(T,Y(:,32)./1368,'y-')
title('FORCINGS','FontWeight','bold')
xlim([whenstart whenend])
ylabel('Relative strength')


%%%%%%% CARBON CONSERVATION
if conservationcheck == 1
totalcarbon=(Y(A(1),3)+Y(A(1),5)+Y(A(1),6)  -(Y(1,3)+Y(1,5)+Y(1,6)))
end



end


