function dy = snowball_equations(t,y)

%%%%%%% Snowball Model used in Mills et al. (2011)
%%%%%%% Benjamin Mills. Dec 2012. benjaminmills@live.com
%%%%%%%
%%%%%%% Simplification of Minimal model to assess effects of transport limitation of
%%%%%%% weathering and snowball glaciations in the Neoproterozoic
%%%%%%% 
%%%%%%% Updated to include ocean crust carbonatization as a CO2 sink
%%%%%%% (see thesis chap. 6)
%%%%%%%
%%%%%%% Model equations file
%%%%%%%
%%%%%%% No user panel here, simple forcing alterations can be made in the
%%%%%%% frontend file.



dy = zeros(24,1);  
C13=zeros(6,1);


global oxidwlimit
global trigtemp
global escapetemp
global albedo_base
global albedo_ice
global icelimit
global snowb
global glaciate
global silcap
global carbcap
global dmocb
global rhobase
global rhoup
global dbase
global dup
global ebase
global eup
global telltime
global alphaOCC
global Sfixed
global k1
global k2
global k3
global k4
global k5
global k7
global k8
global k9
global k10
global a
global b
global d
global rp
global P0
global O0
global A0
global G0
global C0
global Q0
global M0
global notesteady
global steadytime
global kcarbw
global silcapflour
global carbcapflour
global flourmax
global silcapREAL
global carbcapREAL
global flourbase
global steadytemptolerance   
global whenstart
global whenend
global OCCLIMIT
global kocc


%%%%%%% define functions

%%%%%%% degassing/epsilon simple functions allowing for smooth changes
degass=inline('(x-w).*(1./(1+exp(-2*(3*10^-7).*(z-3.75*10^9))))+w   +y.*0');  % smooth ascent  f(rhobase,rhoup,0,t) (10ma)
e=inline('(x-w).*(1./(1+exp(-2*(3*10^-7).*(z-3.75*10^9))))+w   +y.*0');  % smooth ascent  f(rhobase,rhoup,0,t) (10ma)

%%%%%%% rho shifts then returns to base, approx 150Myr perturbation.
rho=inline('(x-w).*(1./(1+exp(-2*(6*10^-8).*(z-3.75*10^9))))+w   +  (w-x).*(1./(1+exp(-2*(6*10^-8).*(z-3.92*10^9))))      +y.*0');  % smooth ascent  f(rhobase,rhoup,0,t) (10ma)

%%%%%%% atfrac(A), valid for albedo={0.3,0.6} only
atfrac=inline(' 0.8.*( x./(x  +  (    1  +   5.*( ( b-0.3 )./ 0.35 )    ).*10^20  ) )  ');

%%%%%%% temp(Sfixed,albedo,CO2atm) (LBL)
Temp=inline('        ((   (a.*(1-b))./(4.*(1-(0.773./2)).*5.67*10^-8)  ).^0.25)          + 0.1815.*(        0.2507.*((log10(x)).^4)  +  3.9216.*((log10(x)).^3) + 23.8113.*((log10(x)).^2) + 83.4113.*((log10(x))) + 131.6138        )  ');


%%%%%%% glacial weathering reduction
% f(icelimit,albedosnow, 0 , ALB)
glac = inline( '10.^ -( (a).* ( 1  -   (  0.5+ 0.5 .*sign(b - 0.01 - d)  )  )    + c.*0  )'  ) ;
glacoxidw = glac;


%%%%%%% weathering functions

%%capped function fco2()
fco2=inline(' (z-(exp(7537.69.*((x-288.15)./(x.*288.15))).*((exp( 0.03.*(x-288.15) )).^0.65).*((y).^0.5).*a.*b) ).*(1./(1+exp(-1.*(100).*((exp(7537.69.*((x-288.15)./(x.*288.15))).*((exp( 0.03.*(x-288.15) )).^0.65).*((y).^0.5).*a.*b) -z))))  + (exp(7537.69.*((x-288.15)./(x.*288.15))).*((exp( 0.03.*(x-288.15) )).^0.65).*((y).^0.5).*a.*b) ');
%capped function gco2()
gco2=inline(' (z-(exp(7537.69.*((x-288.15)./(x.*288.15))).*((exp( 0.03.*(x-288.15) )).^0.65).*((y).^0.5).*a.*b) ).*(1./(1+exp(-1.*(100).*((exp(7537.69.*((x-288.15)./(x.*288.15))).*((exp( 0.03.*(x-288.15) )).^0.65).*((y).^0.5).*a.*b) -z))))  + (exp(7537.69.*((x-288.15)./(x.*288.15))).*((exp( 0.03.*(x-288.15) )).^0.65).*((y).^0.5).*a.*b) ');

%%%%%%% for time to stability, assume weathering rate fixed at Wmax
% fco2 = inline(' a.*b.*x.*y.*0 + z ');
% gco2 = inline(' a.*b.*x.*y.*0 + z ');


%%%%%%% ocean anoxic fraction (truncated)
anox=inline('(0.*(1 - 0.5.*(sign((1-((0.86*(x./(3.7*10^19)))./(y./(3.1*10^15))))) + 1)) + (1-((0.86.*(x./(3.7*10^19)))./(y./(3.1*10^15)))).*0.5.*(sign((1-((0.86*(x./(3.7*10^19)))./(y./(3.1*10^15)))))+1 ))');

%%%%%%% C to P burial ratio
CPsea=inline('250');  

%%%%%%% CALCULATE COMPOSITION USING C12 VALUE (comp=d13C value) comp(C12,totalC)
comp=inline('((((y-x)./(x))./0.0112372)-1).*1000');
%%%%%%% reverse
amountc12=inline('(x/(1+  y*( (z/1000) +1 )  ) )');  %% (x/(1+  y*( (z/1000) +1 )  ) )


%%%%%%% dmccb no fractionaton
dmccbnofrac=inline('x.*z.*0 +1');

%%%%%%% variable dmccb
dmccb=inline(  '  x.*( (9483./z) -23.89) +15.1 -4232./z  ');     % f(atfrac,tempK)    


%%%%%%% albfind(alb,alb_to_find), to change between albedos.
albfind=inline('  y-x  ');


%%%%% step function for weathering rate cap dependence on flour abundance
% (  0.5+ 0.5 .*sign(flour2 - (10^18)) )
flourfunc = inline( '   (a-d).* ( 1  -   (  0.5+ 0.5 .*sign(c - b)  )  ) '  ) ;

%%%%%%% function from vance 2009. 
% flourfunc = inline( '  ( (a-d).* ( 1  -   (  0.5+ 0.5 .*sign(c - b)  )  )  ).*  (         ( ( t-(3.7*10^9) )./1000 ).^-0.61          )        '  ) ;





%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%% ALBEDO FLIP PARAMETERISATION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



% restriction on glaciation until spin up is complete
 if t<3.65*10^9
     glaciate=2;
 else
    if Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ) <= trigtemp
        glaciate=1;
    else
        glaciate=0;
    end
 end

 
 
% glaciation effects
if glaciate ==1
%     dy(15)=0.000001*albflipup(y(15),albedo_ice);
     dy(15)=0.00005*albfind(y(15),albedo_ice);
end

   
% snowball complete
if y(15)>=albedo_ice
    snowb=1;
end


        
% warming trigger
if snowb==1
    if Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ) > escapetemp
       glaciate=0;
    end
end


% warming effects
if glaciate <0.5
%   dy(15)=0.00001*albflipdown(y(15),albedo_base);
    dy(15)=0.01*albfind(y(15),albedo_base);
end


% warming complete
if y(15)<= albedo_base + 0.1
    snowb=0;
end




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%% END OF ALBEDO FLIP PARAMETERISATION %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




%%%%%%% ROCK FLOUR


%%%%%%% Constant weathering rate cap when rock flour is present
silcapREAL = silcap + flourfunc(silcapflour, flourmax, y(4), silcap) ;
carbcapREAL = carbcap + flourfunc(carbcapflour, flourmax, y(4), carbcap) ;

%%%%%%% alternative for no flour
% silcapREAL = silcap;
% carbcapREAL = carbcap;


%%%%%%% accumilation of rock flour during glaciation
if snowb == 1
  dy(4) =  0.000001*albfind(y(4),flourbase);
end


%%%%%%% usegae of flour after deglaciation
if snowb <= 0.5
    if y(4) < flourmax
        dy(4) =    k5*fco2(glac(icelimit,albedo_ice,albedo_base,y(15)),rho(rhobase,rhoup,y(16),t),Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ) , (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0)) , silcapREAL)  ;
    else
        dy(4) = 0 ;

    end
end




%%%%%%% ADDITION: OCC RATE 

OCC_kinetic = (kocc)*((y(3)/A0)^alphaOCC )*1.2 ;

%%%%%%% fixed transport limit for OCC limit
if OCC_kinetic > (kocc)*OCCLIMIT
    OCC = (kocc)*OCCLIMIT ;
else 
    OCC = OCC_kinetic ;
end




%%%%%%% RESERVOIR CALCULATIONS

% PHOSPHATE (P)
dy(1)= e(ebase,eup,y(16),t)*k8*( (2/12)*fco2(glac(icelimit,albedo_ice,albedo_base,y(15)),rho(rhobase,rhoup,y(16),t),Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ),(y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0)),silcapREAL)  +       (5/12)*gco2(glac(icelimit,albedo_ice,albedo_base,y(15)),rho(rhobase,rhoup,y(16),t),Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ),(y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0)),carbcapREAL)     +   (5/12)*glacoxidw(oxidwlimit,albedo_ice,albedo_base,y(15))*(y(5)/G0)*((y(2)/O0)^a) )   -   ( (k1*((y(1)/P0)^b))/CPsea(anox(y(2),y(1))) )  -     k2*(   (k1*((y(1)/P0)^b))/(k1) )   -(k3/k4)*(1-anox(y(2),y(1)))*(  ( (k1*((y(1)/P0)^b))  )/(k1) )    ;     

% OXYGEN  (O)
dy(2)=0;

%CARBON DIOXIDE  (A)
carb2 =   -OCC   -(k1.*((y(1)./P0).^b))     -k5.*fco2(glac(icelimit,albedo_ice,albedo_base,y(15)),rho(rhobase,rhoup,y(16),t),Temp(Sfixed, y(15), (y(3)./A0).*(atfrac( y(15) , y(3))./atfrac( 0.3 , A0)).*(280/1000000) ),(y(3)/A0).*(atfrac( y(15) , y(3))./atfrac( 0.3 , A0)),silcapREAL)   +k7.*glacoxidw(oxidwlimit,albedo_ice,albedo_base,y(15)).*(y(5)/G0).*((y(2)./O0).^a)    +k9.*degass(dbase,dup,y(16),t).*((y(2)./O0).^d).*(y(5)./G0)   +k10*degass(dbase,dup,y(16),t).*(y(6)./C0)     + kcarbw.*gco2(glac(icelimit,albedo_ice,albedo_base,y(15)),rho(rhobase,rhoup,y(16),t),Temp(Sfixed, y(15), (y(3)./A0).*(atfrac( y(15) , y(3))./atfrac( 0.3 , A0))*(280/1000000) ),(y(3)./A0).*(atfrac( y(15) , y(3))./atfrac( 0.3 , A0)),carbcapREAL)    -   kcarbw.*gco2(glac(icelimit,albedo_ice,albedo_base,y(15)),rho(rhobase,rhoup,y(16),t),Temp(Sfixed, y(15), (y(3)./A0)*(atfrac( y(15) , y(3))./atfrac( 0.3 , A0)).*(280/1000000) ),(y(3)./A0).*(atfrac( y(15) , y(3))./atfrac( 0.3 , A0)),carbcapREAL)    ;

if notesteady == 1
        dy(3) = 0  ;
else
    if y(3) + carb2 <=0
    dy(3) = -y(3);
    else
    dy(3)=carb2;
    end
end


%BURIED ORG C  (G)
dy(5)=0;


%BURIED CARB C  (C)
dy(6)=0;



%%%%%%% ISOTOPES


%%%%%%% ghost 1 : temp dependent mccb frac

% C12(A)
dy(8)=  -OCC*(y(8)/y(3))     - ( (k1*((y(1)/P0)^b))  )*(1/(1+rp*( ( (comp(y(8),y(3)) +dmocb  ) /1000) +1)))         -k5*fco2(glac(icelimit,albedo_ice,albedo_base,y(15)),rho(rhobase,rhoup,y(16),t),Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ),(y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0)),silcapREAL)*(1/(1+rp*( ( (comp(y(8),y(3)) + dmccb(atfrac( y(15) , y(3)),Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ))  ) /1000) +1)))    +k7*glacoxidw(oxidwlimit,albedo_ice,albedo_base,y(15))*(y(5)/G0)*((y(2)/O0)^a)*(y(10)/y(5))    +k9*degass(dbase,dup,y(16),t)*((y(2)/O0)^d)*(y(5)/G0)*(y(10)/y(5))   +k10*degass(dbase,dup,y(16),t)*(y(6)/C0)*(y(11)/y(6))         +     kcarbw*gco2(glac(icelimit,albedo_ice,albedo_base,y(15)),rho(rhobase,rhoup,y(16),t),Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ),(y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0)),carbcapREAL)*(y(11)/y(6))    -  kcarbw*gco2(glac(icelimit,albedo_ice,albedo_base,y(15)),rho(rhobase,rhoup,y(16),t),Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ),(y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0)),carbcapREAL)*(1/(1+rp*( ( (comp(y(8),y(3)) + dmccb(atfrac( y(15) , y(3)),Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ))  ) /1000) +1)))   ;

% C12(G)
dy(10)=0;
% C12(C)
dy(11)=0;


%%%%%%% ghost 2: parrallel run with no temp dep frac on mccb

% C12(A)
dy(18)=    -OCC*(y(18)/y(3))  - ( (k1*((y(1)/P0)^b))  )*(1/(1+rp*( ( (comp(y(18),y(3)) +dmocb  ) /1000) +1)))         -k5*fco2(glac(icelimit,albedo_ice,albedo_base,y(15)),rho(rhobase,rhoup,y(16),t),Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ),(y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0)),silcapREAL)*(1/(1+rp*( ( (comp(y(18),y(3)) + dmccbnofrac(atfrac( y(15) , y(3)),Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ))  ) /1000) +1)))    +k7*glacoxidw(oxidwlimit,albedo_ice,albedo_base,y(15))*(y(5)/G0)*((y(2)/O0)^a)*(y(19)/y(5))    +k9*degass(dbase,dup,y(16),t)*((y(2)/O0)^d)*(y(5)/G0)*(y(19)/y(5))   +k10*degass(dbase,dup,y(16),t)*(y(6)/C0)*(y(20)/y(6))     +     kcarbw*gco2(glac(icelimit,albedo_ice,albedo_base,y(15)),rho(rhobase,rhoup,y(16),t),Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ),(y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0)),carbcapREAL)*(y(20)/y(6))     - kcarbw*gco2(glac(icelimit,albedo_ice,albedo_base,y(15)),rho(rhobase,rhoup,y(16),t),Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ),(y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0)),carbcapREAL)*(1/(1+rp*( ( (comp(y(18),y(3)) + dmccbnofrac(atfrac( y(15) , y(3)),Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ))  ) /1000) +1)))    ;

% C12(G)
dy(19)=0;
% C12(C)
dy(20)=0;


% dy(8)=0;
% dy(10)=0;
% dy(11)=0;
% dy(18)=0;
% dy(19)=0;
% dy(20)=0;




%%%%%%% tracking reservoirs

dy(21) = fco2(glac(icelimit,albedo_ice,albedo_base,y(15)),rho(rhobase,rhoup,y(16),t),Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ),(y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0)),silcapREAL)  -y(21) ;
dy(22) = gco2(glac(icelimit,albedo_ice,albedo_base,y(15)),rho(rhobase,rhoup,y(16),t),Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ),(y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0)),carbcapREAL)  -y(22)  ;
dy(23) = Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ) -y(23) ;
dy(24) = (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) - y(24) ;
dy(25) = OCC - y(25) ;





%%%%%%% option to record time when temp reaches steady state (for perturbation experiment) NOTE: THIS IS HARD CODED PER SITUATION USING MODEL RESULTS.

if Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ) < 284.9  + steadytemptolerance       %%D=1
% if Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ) < 285.7  + steadytemptolerance        %%D=1.5
% if Temp(Sfixed, y(15), (y(3)/A0)*(atfrac( y(15) , y(3))/atfrac( 0.3 , A0))*(280/1000000) ) < 286.2   + steadytemptolerance         %%D=2
       
        
    if notesteady==0
        steadytime=t;
       notesteady=1;
    end
end






if telltime==1
t
end


